#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2008 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Initial deployment of generations to schooltool.gradebook.

Manually evolves to generation 1. Needed to support upgrade from a
database that did not have generations (schooltool.gradebook << 0.4.9)
"""

import evolve1
import evolve2
import evolve3


def evolve(context):
    evolve1.evolve(context)
    evolve2.evolve(context)
    evolve3.evolve(context)

